## Copyright (C) 2019 John Donoghue <john.donoghue@ieee.org>
## 
## This program is free software: you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see
## <https://www.gnu.org/licenses/>.

## -*- texinfo -*- 
## @deftypefn {} {@var{devlist} =} mididevinfo ()
## @deftypefnx {} {} mididevinfo ()
## Retrieve the midi devices detected within the system.
##
## The list will be stored with variable @var{devlist} as either a input or output device.
## If no output vraiable is provided, the devices will be displayed.
##
## @seealso{mididevice}
## @end deftypefn

function out = mididevinfo ()
  # get dev list
  data = __mididevinfo__();

  # output variable to store to - so assign devices to it
  if nargout > 0
    out = {};
    out.input = {};
    out.output = {};

    for i=1:length(data)
      val = {};
      val.Name = data(i).Name;
      val.Interface = data(i).Interface;
      val.ID = data(i).ID;
      if strcmp (data(i).Direction, "input")
	out.input{end+1} = val;
      else
	out.output{end+1} = val;
      endif
    endfor
  # no output - just display the devices
  else
    printf ("MIDI devices available\n");
    printf ("ID Direction Interface  Name\n");

    for i=1:length(data)
      printf ("%2d %12s %10s %s\n", data(i).ID, data(i).Direction, data(i).Interface, data(i).Name);
    endfor
  endif

endfunction

%!test
%! a = mididevinfo;
%! assert(length(a) > 0);
%! x = a.input;
%! x = a.output;
